aboutsummaryrefslogtreecommitdiff
path: root/keyboards/doppelganger
diff options
context:
space:
mode:
authorRyan <[email protected]>2024-05-03 15:21:29 +1000
committerGitHub <[email protected]>2024-05-03 15:21:29 +1000
commitd09a06a1b354760fd0e64a453abade972900e885 (patch)
tree88d94640f4507ac8d7f570607423825bec3c6f89 /keyboards/doppelganger
parent5426a7a129acf2ff5c8b435014747f1238e17965 (diff)
downloadqmk_firmware-d09a06a1b354760fd0e64a453abade972900e885.tar.gz
qmk_firmware-d09a06a1b354760fd0e64a453abade972900e885.zip
Update GPIO API usage in keyboard code (#23361)
Diffstat (limited to 'keyboards/doppelganger')
-rw-r--r--keyboards/doppelganger/doppelganger.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/keyboards/doppelganger/doppelganger.c b/keyboards/doppelganger/doppelganger.c
index 9a9fc0679f..4a62fdf45f 100644
--- a/keyboards/doppelganger/doppelganger.c
+++ b/keyboards/doppelganger/doppelganger.c
@@ -16,30 +16,30 @@
#include "quantum.h"
void keyboard_pre_init_kb(void) {
- setPinOutput(C6);
- setPinOutput(B0);
+ gpio_set_pin_output(C6);
+ gpio_set_pin_output(B0);
}
bool led_update_kb(led_t led_state) {
bool res = led_update_user(led_state);
if (res) {
// writePin sets the pin high for 1 and low for 0.
// In this example the pins are inverted, setting
// it low/0 turns it on, and high/1 turns the LED off.
// This behavior depends on whether the LED is between the pin
// and VCC or the pin and GND.
- writePin(C6, !led_state.caps_lock);
+ gpio_write_pin(C6, !led_state.caps_lock);
}
return res;
}
__attribute__((weak)) layer_state_t layer_state_set_user(layer_state_t state) {
- writePin(B0, !(state & (1UL << 1)));
+ gpio_write_pin(B0, !(state & (1UL << 1)));
return state;
}
// Override core logic as we reuse SPLIT_HAND_PIN within matrix pins
bool is_keyboard_left(void) {
- setPinInput(SPLIT_HAND_PIN);
- return readPin(SPLIT_HAND_PIN);
+ gpio_set_pin_input(SPLIT_HAND_PIN);
+ return gpio_read_pin(SPLIT_HAND_PIN);
}
@@ -16,30 +16,30 @@
bool res = led_update_user(led_state);
if (res) {
- // writePin sets the pin high for 1 and low for 0.
+ // gpio_write_pin sets the pin high for 1 and low for 0.
// In this example the pins are inverted, setting
// it low/0 turns it on, and high/1 turns the LED off.